@@ -1,6 +1,6 @@
 package Spreadsheet::ParseXLSX;
 our $AUTHORITY = 'cpan:DOY';
-$Spreadsheet::ParseXLSX::VERSION = '0.19';
+$Spreadsheet::ParseXLSX::VERSION = '0.20';
 use strict;
 use warnings;
 use 5.008;
@@ -927,7 +927,7 @@ Spreadsheet::ParseXLSX - parse XLSX files
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
@@ -940,6 +940,10 @@ version 0.19
 =head1 DESCRIPTION
 
 This module is an adaptor for L<Spreadsheet::ParseExcel> that reads XLSX files.
+For documentation about the various data that you can retrieve from these
+classes, please see L<Spreadsheet::ParseExcel>,
+L<Spreadsheet::ParseExcel::Workbook>, L<Spreadsheet::ParseExcel::Worksheet>,
+and L<Spreadsheet::ParseExcel::Cell>.
 
 =head1 METHODS
 
@@ -1013,6 +1017,14 @@ although this may have other consequences such as memory leaks.
 
 =item Intra-cell formatting is discarded
 
+=item Shared formulas are not supported
+
+Shared formula support will require an actual formula parser and quite a bit of
+custom logic, since the only thing stored in the document is the formula for
+the base cell - updating the cell references in the formulas in the rest of the
+cells is handled by the application. Values for these cells are still handled
+properly.
+
 =back
 
 In addition, there are still a few areas which are not yet implemented (the
